#!/usr/bin/env ruby
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2 of the License, or (at your
# option) any later version. This program is distributed in the hope that
# it will be useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
# the GNU General Public License for more details. You should have
# received a copy of the GNU General Public License along with this
# program; if not, write to the Free Software Foundation, Inc., 59 Temple
# Place - Suite 330, Boston, MA 02111-1307, USA.
#
# Preferences Dialog
#

require 'gtk2'
require 'gconf2'

class PreferencesDialog

 private

 def maybe_update(key, value)
	if $gconf[key] != value
		$gconf[key] = value
	end
 end

 public

 def initialize(gconf_root)
	@gconf_root = gconf_root

	@dialog = Gtk::Dialog.new
	@dialog.title = "Preferences"

	dialog_vbox = @dialog.vbox
	dialog_vbox.spacing = 2
	dialog_vbox.homogeneous = false

	vbox = Gtk::VBox.new
	vbox.border_width = 5
	vbox.homogeneous = false
	vbox.spacing = 10
	dialog_vbox.pack_start(vbox, false, false, 5)

	# username / password

	title = Gtk::Label.new
	title.set_markup("<b>Account Settings</b>")

	temp_hbox = Gtk::HBox.new
	temp_hbox.pack_start(title, false, false, 5)
	vbox.pack_start(temp_hbox, true, true, 0)

	table = Gtk::Table.new(2, 2)

	# username

	username_label = Gtk::Label.new("Username:")
	username_label.justify = Gtk::JUSTIFY_LEFT
	table.attach_defaults(username_label, 0, 1, 0, 1)

	@username_box = Gtk::Entry.new
	table.attach_defaults(@username_box, 1, 2, 0, 1)
	table.row_spacings = 6
	table.column_spacings = 12

	# password

	password_label = Gtk::Label.new("Password:")
	password_label.justify = Gtk::JUSTIFY_LEFT
	table.attach_defaults(password_label, 0, 1, 1, 2)

	@password_box = Gtk::Entry.new
	@password_box.visibility = false
	table.attach_defaults(@password_box, 1, 2, 1, 2)

	temp_hbox = Gtk::HBox.new
	temp_hbox.pack_start(table, false, false, 18)
	vbox.pack_start(temp_hbox, false, false, 0)

	# update freq
	
	title = Gtk::Label.new
	title.set_markup("<b>Mail Check</b>")
	temp_hbox = Gtk::HBox.new
	temp_hbox.pack_start(title, false, false, 5)
	vbox.pack_start(temp_hbox, true, true, 0)

	hbox = Gtk::HBox.new
	hbox.homogeneous = false
	hbox.spacing = 3
	hbox.pack_start(Gtk::Label.new("Check for new mail every"))
	@update_freq = Gtk::SpinButton.new(10, 1000, 10)
	hbox.pack_start(@update_freq)
	hbox.pack_start(Gtk::Label.new("seconds"))
	
	temp_hbox = Gtk::HBox.new
	temp_hbox.pack_start(hbox, false, false, 18)
	vbox.pack_start(temp_hbox, false, false, 0)

	# action buttons
	
	close_button = Gtk::Button.new(Gtk::Stock::CLOSE)

	@username_key = "#{gconf_root}/username"
	@password_key = "#{gconf_root}/password"
	@update_freq_key = "#{gconf_root}/update_time"

	close_button.signal_connect('clicked') do
		maybe_update(@username_key, @username_box.text)
		maybe_update(@password_key, @password_box.text)
		$gconf[@update_freq_key] = @update_freq.value
		@dialog.hide
	end

	@dialog.add_action_widget(close_button, Gtk::Dialog::RESPONSE_NONE)
 end

 def display
 	if $gconf[@username_key] != nil then
	 	@username_box.text = $gconf[@username_key]
	end
	if $gconf[@password_key] != nil then
	 	@password_box.text = $gconf[@password_key]
	end
	@update_freq.value = if $gconf[@update_freq_key] != nil then
			$gconf[@update_freq_key]
		else
			300
		end
	@dialog.show_all
 end

end

